.. data classes

Data Classes
============

All ``emdfile`` data classes inherit from the :ref:`Node <Node>` class, which adds core tree-building and metadata storage functionality.  Each additionally has its own data and built-in metadata interface.

.. _Array:

*****
Array
*****

.. autoclass:: emdfile::Array
    :members:

.. _PointList:

*********
PointList
*********

.. autoclass:: emdfile::PointList
    :members:

.. _PointListArray:

**************
PointListArray
**************

.. autoclass:: emdfile::PointListArray
    :members:


